pub fn connect_isolated_tcp_direct_with_inbound<InboundService>(
network: &Network,
addr: impl Into<PeerSocketAddr>,
user_agent: String,
inbound_service: InboundService,
) -> impl Future<Output = Result<Client, BoxError>>Expand description
Creates an isolated Zcash peer connection using the provided data stream. This function is for testing purposes only.
See connect_isolated_with_inbound and connect_isolated_tcp_direct for details.
Privacy
This function can make the isolated connection send different responses to peers, which makes it stand out from other isolated connections from other peers.