VersionMessage

Struct VersionMessage 

pub struct VersionMessage {
    pub version: Version,
    pub services: PeerServices,
    pub timestamp: DateTime<Utc>,
    pub address_recv: AddrInVersion,
    pub address_from: AddrInVersion,
    pub nonce: Nonce,
    pub user_agent: String,
    pub start_height: Height,
    pub relay: bool,
}
A version message.

Note that although this is called version in Bitcoin, its role is really analogous to a ClientHello message in TLS, used to begin a handshake, and is distinct from a simple version number.

This struct provides a type that is guaranteed to be a version message, and allows Message::Version fields to be accessed directly.

Bitcoin reference

Fields

version: Version

The network version number supported by the sender.

services: PeerServices

The network services advertised by the sender.

timestamp: DateTime<Utc>

The time when the version message was sent.

This is a 64-bit field. Zebra rejects out-of-range times as invalid.

TODO: replace with a custom DateTime64 type (#2171)

address_recv: AddrInVersion

The network address of the node receiving this message, and its advertised network services.

Q: how does the handshake know the remote peer’s services already?

address_from: AddrInVersion

The network address of the node sending this message, and its advertised network services.

nonce: Nonce

Node random nonce, randomly generated every time a version packet is sent. This nonce is used to detect connections to self.

user_agent: String

The Zcash user agent advertised by the sender.

start_height: Height

The last block received by the emitting node.

relay: bool

Whether the remote peer should announce relayed transactions or not, see BIP 0037.

Zebra does not implement the bloom filters in BIP 0037. Instead, it only relays:

  • newly verified best chain block hashes and mempool transaction IDs,
  • after it reaches the chain tip.