pub type BoxError = Box<dyn Error + Send + Sync + 'static>;Expand description
Type alias to make working with tower traits easier.
Note: the ’static lifetime bound means that the type cannot have any non-’static lifetimes, (e.g., when a type contains a borrow and is parameterized by ’a), not that the object itself has ’static lifetime.
Aliased Type
pub struct BoxError(/* private fields */);Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 16 bytes