pub struct PeerSocketAddr(SocketAddr);Expand description
A thin wrapper for SocketAddr which hides peer IP addresses in logs and metrics.
Tuple Fields
0: SocketAddrImplementations
Sourceimpl PeerSocketAddr
impl PeerSocketAddr
Sourcepub fn unspecified() -> Self
pub fn unspecified() -> Self
Returns an unspecified PeerSocketAddr, which can’t be used for outbound connections.
Sourcepub fn remove_socket_addr_privacy(&self) -> SocketAddr
pub fn remove_socket_addr_privacy(&self) -> SocketAddr
Return the underlying SocketAddr, which allows sensitive peer address information to
be printed and logged.
Sourcepub fn is_localhost(&self) -> bool
pub fn is_localhost(&self) -> bool
Returns true if the inner SocketAddr’s IP is the localhost IP.
Methods from Deref<Target = SocketAddr>
1.7.0 · Sourcepub fn ip(&self) -> IpAddr
pub fn ip(&self) -> IpAddr
Returns the IP address associated with this socket address.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.ip(), IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)));1.9.0 · Sourcepub fn set_ip(&mut self, new_ip: IpAddr)
pub fn set_ip(&mut self, new_ip: IpAddr)
Changes the IP address associated with this socket address.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let mut socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
socket.set_ip(IpAddr::V4(Ipv4Addr::new(10, 10, 0, 1)));
assert_eq!(socket.ip(), IpAddr::V4(Ipv4Addr::new(10, 10, 0, 1)));1.0.0 · Sourcepub fn port(&self) -> u16
pub fn port(&self) -> u16
Returns the port number associated with this socket address.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.port(), 8080);1.9.0 · Sourcepub fn set_port(&mut self, new_port: u16)
pub fn set_port(&mut self, new_port: u16)
Changes the port number associated with this socket address.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let mut socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
socket.set_port(1025);
assert_eq!(socket.port(), 1025);1.16.0 · Sourcepub fn is_ipv4(&self) -> bool
pub fn is_ipv4(&self) -> bool
Returns true if the IP address in this SocketAddr is an
IPv4 address, and false otherwise.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.is_ipv4(), true);
assert_eq!(socket.is_ipv6(), false);1.16.0 · Sourcepub fn is_ipv6(&self) -> bool
pub fn is_ipv6(&self) -> bool
Returns true if the IP address in this SocketAddr is an
IPv6 address, and false otherwise.
Examples
use std::net::{IpAddr, Ipv6Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 65535, 0, 1)), 8080);
assert_eq!(socket.is_ipv4(), false);
assert_eq!(socket.is_ipv6(), true);Trait Implementations
Sourceimpl Arbitrary for PeerSocketAddr
impl Arbitrary for PeerSocketAddr
Sourcetype Parameters = <SocketAddr as Arbitrary>::Parameters
type Parameters = <SocketAddr as Arbitrary>::Parameters
arbitrary_with accepts for configuration
of the generated Strategy. Parameters must implement Default.Sourcetype Strategy = Map<<SocketAddr as Arbitrary>::Strategy, fn(SocketAddr) -> PeerSocketAddr>
type Strategy = Map<<SocketAddr as Arbitrary>::Strategy, fn(SocketAddr) -> PeerSocketAddr>
Strategy used to generate values of type Self.Sourcefn arbitrary_with(_top: Self::Parameters) -> Self::Strategy
fn arbitrary_with(_top: Self::Parameters) -> Self::Strategy
Sourceimpl Clone for PeerSocketAddr
impl Clone for PeerSocketAddr
Sourcefn clone(&self) -> PeerSocketAddr
fn clone(&self) -> PeerSocketAddr
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PeerSocketAddr
impl Debug for PeerSocketAddr
Sourceimpl DerefMut for PeerSocketAddr
impl DerefMut for PeerSocketAddr
Sourceimpl<'de> Deserialize<'de> for PeerSocketAddr
impl<'de> Deserialize<'de> for PeerSocketAddr
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Display for PeerSocketAddr
impl Display for PeerSocketAddr
Sourceimpl<S> From<S> for PeerSocketAddrwhere
S: Into<SocketAddr>,
impl<S> From<S> for PeerSocketAddrwhere
S: Into<SocketAddr>,
Sourceimpl FromStr for PeerSocketAddr
impl FromStr for PeerSocketAddr
Sourceimpl Hash for PeerSocketAddr
impl Hash for PeerSocketAddr
Sourceimpl JsonSchema for PeerSocketAddr
impl JsonSchema for PeerSocketAddr
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
$ref keyword. Read moreSourceimpl Ord for PeerSocketAddr
impl Ord for PeerSocketAddr
Sourcefn cmp(&self, other: &PeerSocketAddr) -> Ordering
fn cmp(&self, other: &PeerSocketAddr) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for PeerSocketAddr
impl PartialEq for PeerSocketAddr
Sourceimpl PartialOrd for PeerSocketAddr
impl PartialOrd for PeerSocketAddr
Sourceimpl Serialize for PeerSocketAddr
impl Serialize for PeerSocketAddr
Sourceimpl Deref for PeerSocketAddr
impl Deref for PeerSocketAddr
impl Copy for PeerSocketAddr
impl Eq for PeerSocketAddr
impl StructuralPartialEq for PeerSocketAddr